@@ -1,11 +1,12 @@
 from django.conf.urls import url, patterns
 from .resources import RestroomResource
 from .views import RestroomItemView, RestroomListView
+from .resources import api_key_resource
 
 
 class API(object):
     def __init__(self):
-        self.resources = []
+        self.resources = [api_key_resource]
 
     def register(self, model, options={}):
         self.resources.append(RestroomResource(model, options))
